diff src/browser/libervia_main.py @ 536:048ae7314156

browser_side: temporary way to display the OTR state in the LiberviaWidget header
author souliane <souliane@mailoo.org>
date Sun, 07 Sep 2014 16:40:33 +0200
parents 19fc2ebc02dd
children 530f3fc3e3d7
line wrap: on
line diff
--- a/src/browser/libervia_main.py	Fri Sep 05 19:29:35 2014 +0200
+++ b/src/browser/libervia_main.py	Sun Sep 07 16:40:33 2014 +0200
@@ -734,8 +734,10 @@
                 lib_wid.printInfo(msg)
             else:
                 lib_wid.printMessage(from_jid, msg, extra)
+            if 'header_info' in extra:
+                lib_wid.setHeaderInfo(extra['header_info'])
         else:
             # FIXME: "info" message will be lost here
             if not self.contact_panel.isContactInRoster(other.bare):
                 self.contact_panel.updateContact(other.bare, {}, [C.GROUP_NOT_IN_ROSTER])
             # The message has not been shown, we must indicate it
@@ -734,8 +734,10 @@
         else:
-            # FIXME: "info" message will be lost here
+            # FIXME: "info" message and header info will be lost here
             if not self.contact_panel.isContactInRoster(other.bare):
                 self.contact_panel.updateContact(other.bare, {}, [C.GROUP_NOT_IN_ROSTER])